pub struct ClassifierDecl {
pub keyword: String,
pub text: String,
}Expand description
Package-level KerML classifier declaration captured as an explicit dedicated node.
Fields
keyword: Stringtext: StringTrait Implementations
Sourceimpl Clone for ClassifierDecl
impl Clone for ClassifierDecl
Sourcefn clone(&self) -> ClassifierDecl
fn clone(&self) -> ClassifierDecl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClassifierDecl
impl Debug for ClassifierDecl
impl Eq for ClassifierDecl
Sourceimpl PartialEq for ClassifierDecl
impl PartialEq for ClassifierDecl
Sourcefn eq(&self, other: &ClassifierDecl) -> bool
fn eq(&self, other: &ClassifierDecl) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ClassifierDecl