pub struct ExtendedLibraryDecl {
pub bnf_production: String,
pub text: String,
}Expand description
Modeled extended SysML/KerML declaration family not yet represented by dedicated concrete nodes (e.g. concern/message style library declarations).
Fields
bnf_production: Stringtext: StringTrait Implementations
Sourceimpl Clone for ExtendedLibraryDecl
impl Clone for ExtendedLibraryDecl
Sourcefn clone(&self) -> ExtendedLibraryDecl
fn clone(&self) -> ExtendedLibraryDecl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtendedLibraryDecl
impl Debug for ExtendedLibraryDecl
impl Eq for ExtendedLibraryDecl
Sourceimpl PartialEq for ExtendedLibraryDecl
impl PartialEq for ExtendedLibraryDecl
Sourcefn eq(&self, other: &ExtendedLibraryDecl) -> bool
fn eq(&self, other: &ExtendedLibraryDecl) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExtendedLibraryDecl