pub struct FeatureDecl {
pub keyword: String,
pub text: String,
}Expand description
Package-level KerML feature declaration captured as an explicit dedicated node.
Fields
keyword: Stringtext: StringTrait Implementations
Sourceimpl Clone for FeatureDecl
impl Clone for FeatureDecl
Sourcefn clone(&self) -> FeatureDecl
fn clone(&self) -> FeatureDecl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeatureDecl
impl Debug for FeatureDecl
impl Eq for FeatureDecl
Sourceimpl PartialEq for FeatureDecl
impl PartialEq for FeatureDecl
Sourcefn eq(&self, other: &FeatureDecl) -> bool
fn eq(&self, other: &FeatureDecl) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FeatureDecl