pub struct OpaqueMemberDecl {
pub keyword: String,
pub name: String,
pub text: String,
pub body: AttributeBody,
}Expand description
Library-tolerant part member preserved without forcing it into an unrelated node shape.
Fields
keyword: Stringname: Stringtext: Stringbody: AttributeBodyTrait Implementations
Sourceimpl Clone for OpaqueMemberDecl
impl Clone for OpaqueMemberDecl
Sourcefn clone(&self) -> OpaqueMemberDecl
fn clone(&self) -> OpaqueMemberDecl
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OpaqueMemberDecl
impl Debug for OpaqueMemberDecl
impl Eq for OpaqueMemberDecl
Sourceimpl PartialEq for OpaqueMemberDecl
impl PartialEq for OpaqueMemberDecl
Sourcefn eq(&self, other: &OpaqueMemberDecl) -> bool
fn eq(&self, other: &OpaqueMemberDecl) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OpaqueMemberDecl