pub struct ParseErrorNode {
pub message: String,
pub code: String,
pub expected: Option<String>,
pub found: Option<String>,
pub suggestion: Option<String>,
pub category: Option<DiagnosticCategory>,
}Expand description
Placeholder node inserted when resilient parsing skips malformed input.
Fields
message: Stringcode: Stringexpected: Option<String>found: Option<String>suggestion: Option<String>category: Option<DiagnosticCategory>Trait Implementations
Sourceimpl Clone for ParseErrorNode
impl Clone for ParseErrorNode
Sourcefn clone(&self) -> ParseErrorNode
fn clone(&self) -> ParseErrorNode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseErrorNode
impl Debug for ParseErrorNode
Sourceimpl PartialEq for ParseErrorNode
impl PartialEq for ParseErrorNode
Sourcefn eq(&self, other: &ParseErrorNode) -> bool
fn eq(&self, other: &ParseErrorNode) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ParseErrorNode
impl StructuralPartialEq for ParseErrorNode