pub fn parse(input: &str) -> Result<RootNamespace, ParseError>Expand description
Parse a SysML v2 textual input into a root namespace AST.
Returns an error if the input is not valid SysML or if not all input is consumed.
pub fn parse(input: &str) -> Result<RootNamespace, ParseError>Parse a SysML v2 textual input into a root namespace AST.
Returns an error if the input is not valid SysML or if not all input is consumed.